pub struct ProgressHandle { /* private fields */ }Expand description
A shared progress handle that nodes can use to report progress, resetting the idle timeout counter.
The handle stores the last progress timestamp as milliseconds since the UNIX epoch using an atomic u64 for lock-free updates.
Implementations
Sourceimpl ProgressHandle
impl ProgressHandle
Sourcepub fn report_progress(&self)
pub fn report_progress(&self)
Report progress, resetting the idle timeout counter.